PyTorch and Tensorflow Support
==============================
.. currentmodule:: deeplake.core.dataset

Deep Lake datasets can be easily converted to Torch dataloaders or Tensorflow datasets for training.

.. autosummary::
    :toctree:
    :nosignatures:

    Dataset.pytorch
    Dataset.tensorflow